#' @title Boston housing data
#' @name boston
#' @description This data set contains the Harrison & Rubinfeld (1978) data corrected for a few minor errors and augmented with the latitude and longitude of the observations.
#' @docType data
#'
#' @format A data frame with 506 observations and 14 variables:
#' \describe{
#'   \item{OBS}{Numeric: a unique identifier for each case, in the interval [1, 506]}
#'   \item{TOWN}Factor: the name of the town on which the property is located, with 92 levels}
#'   \item{TRACT{Numeric: a unique numeric identifier for each census tract, in the interval [1, 5082]}
#'   \item{LONGIT}{Numeric: the longitude of census tract, in the interval [-71.29, -70.81]}
#'   \item{LATIT}{Numeric: the latitude of census tract, in the interval [42.03, 42.58]}
#'   \item{MEDIANVAL}{Numeric: the median value in US$ of the owner-occupied home, in the interval [5000, 50000]}
#'   \item{MEDIANVALC}{Numeric: the corrected median value in US$ of the owner-occupied home, in the interval [5000, 50000]}
#'   \item{CRIM}{Numeric: the per capita crime rate by town, in the interval [0.00632, 88.97620]}
#'   \item{PROPRESLAND}{Numeric: the proportion of residential land zoned for lots over 25,000 sq.ft, in the interval [0, 100]}#' }
#'   \item{INDUS}{Numeric: the proportion of non-retail business acres per town, in the interval [0.46, 27.74]}
#'   \item{ONRIVER}{Factor: whether the census tract on the river, with levels "no", "yes"}
#'   \item{NITROXIDPPM}{Numeric: the nitric oxides concentration (parts per 10 million), in the interval [0.3850, 0.8710]}
#'   \item{ROOMS}{Numeric: the average number of rooms per dwelling, in the interval [3.561, 8.780]}
#'   \item{BEFORE1940}{Numeric: the proportion of owner-occupied units built prior to 1940, in the interval [2.9, 100]}
#'   \item{DISTANCES}{Numeric: the weighted distances to five Boston employment centres, in the interval [1.13, 12.127]}
#'   \item{RADHIWAYS}{Numeric: an index of accessibility to radial highways, in the interval [1, 24]}
#'   \item{PROPTAXRATE}{Numeric: the full-value property-tax rate per US$10000, in the interval [187, 711]}
#'   \item{PUPILTEACHER}{Numeric: the pupil-teacher ratio by town, in the interval [12.6, 22]}
#'   \item{BLACKS}{Numeric: the 1000(B - 0.63)^2 where B is the proportion of blacks by town, in the interval [0.32, 396.9]}
#'   \item{LOWERSTATUS}{Numeric: the percentage of lower status of the population, in the interval [1.73, 37.97]}
#'
#' @details See <boston_1978_DH_DLR_BostonHousingData_JrnlEnvEcoMang.pdf>
#' @source NA
#' @references {Harrison, D. & D.L. Rubinfeld. 1978. Hedonic Housing Prices and the Demand for Clean Air. Journal of Environmental Economics and Management 5. 81-102.}
#' @references {Gilley, O.W. & R.K. Pace. 1996. On the Harrison and Rubinfeld Data. Journal of Environmental Economics and Management 31. 403-405.}
#' @references {Pace, R.K., & O.W. Gilley. 1997. Using the Spatial Configuration of the Data to Improve Estimation. Journal of the Real Estate Finance and Economics 14. 333-340.}
read.delim("boston.csv", stringsAsFactors=TRUE)
