#' @title That-complementation data
#' @name thatcomplementation
#' @description This data set contains corpus-based data on that-complementation ("I thought ___ the Vorlons could have helped earlier" vs. "I thought that the Vorlons could have helped earlier") and many potential predictors.
#' @docType data
#'
#' @format A data frame with 6174 observations/cases and 18 variables:
#' \describe{
#'   \item{CASE}{Numeric: a unique identifier for each case, in the interval [1, 6174]}
#'   \item{CORPUS}{Factor: the corpus from which the example comes, with levels "ICE-GB", "ICLE", "LINDSEI}
#'   \item{FILE}{Factor: the file/speaker for/of the example, with 1047 levels}
#'   \item{MATCHLEMMA}{Factor: the main verb, with 70 levels}
#'   \item{COMPLEMENTIZER}{Factor: whether the complementizer was absent or present, with levels "absent", "present"}
#'   \item{TYPE}{Factor: the kind of complementation, with levels "obj", "sub"}
#'   \item{L1}{Factor: the L1 of the speaker/writer, with levels "English", "German"}
#'   \item{REGISTER}{Factor: whether the example was spoken or written, with levels "spoken", "written"}
#'   \item{L_COMP}{Numeric: the length of the complement clause in characters, in the interval [4, 500]}
#'   \item{L_COMPSUBJ}{Numeric: the length in characters of the complement clause subject, in the interval [1, 189]}
#'   \item{L_COMPREST}{Numeric: the length i} characters of the rest of complement clause, in the interval [4, 500]}
#'   \item{L_MATRV2CC}{Numeric: the length in characters of any material between the verb of the matrix clause and the complement clause, in the interval [0, 69])
#'   \item{L_MATRBE4S}{Numeric: the length in characters of any material before the subject of the matrix clause, in the interval [0, 202]}
#'   \item{L_MATRSUBJ}{Numeric: the length in characters of the subject of the matrix clause, in the interval [1, 175]}
#'   \item{L_MATRS2V}{Numeric: the length in characters of any material between the subject and the verb of the matrix clause, in the interval [0, 119]}
#'   \item{DP_CW}{Numeric: the attraction (measured as Delta P) of the complementation pattern to the matrix clause verb, in the interval [-0.113264, 0.374783]}
#'   \item{DP_WC}{Numeric:the attraction (measured as Delta P) of the matrix clause verb to the complementation pattern, in the interval [-0.521334, 0.480777]}
#'   \item{SURPRISAL}{Numeric: the surprisal of the first word of the complement clause given the last word of the matrix clause, in the interval [1.343, 20.007]}
#' }
#'
#' @details This is a sample of the data set studied in Wulff, Gries, & Lester (2018)
#' @source NA
#' @references \url{https://www.stgries.info/research/2018_SW-STG-NL_OptionalThatOfGermSpanLearners_ApplCognLing.pdf}
read.delim("thatcomplementation.csv", stringsAsFactors=TRUE)
